
#ifndef KCMUTILSCORE_EXPORT_H
#define KCMUTILSCORE_EXPORT_H

#ifdef KCMUTILSCORE_STATIC_DEFINE
#  define KCMUTILSCORE_EXPORT
#  define KCMUTILSCORE_NO_EXPORT
#else
#  ifndef KCMUTILSCORE_EXPORT
#    ifdef KF5KCMUtilsCore_EXPORTS
        /* We are building this library */
#      define KCMUTILSCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCMUTILSCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCMUTILSCORE_NO_EXPORT
#    define KCMUTILSCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCMUTILSCORE_DECL_DEPRECATED
#  define KCMUTILSCORE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCMUTILSCORE_DECL_DEPRECATED_EXPORT
#  define KCMUTILSCORE_DECL_DEPRECATED_EXPORT KCMUTILSCORE_EXPORT KCMUTILSCORE_DECL_DEPRECATED
#endif

#ifndef KCMUTILSCORE_DECL_DEPRECATED_NO_EXPORT
#  define KCMUTILSCORE_DECL_DEPRECATED_NO_EXPORT KCMUTILSCORE_NO_EXPORT KCMUTILSCORE_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCMUTILSCORE_NO_DEPRECATED
#    define KCMUTILSCORE_NO_DEPRECATED
#  endif
#endif

#define KCMUTILSCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KCMUTILSCORE_NO_DEPRECATED) && !defined(KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCMUTILSCORE_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCMUTILSCORE_NO_DEPRECATED_WARNINGS) && !defined(KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCMUTILSCORE_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCMUTILSCORE_NO_DEPRECATED)
#  undef KCMUTILSCORE_DEPRECATED
#  define KCMUTILSCORE_DEPRECATED_EXPORT KCMUTILSCORE_EXPORT
#  define KCMUTILSCORE_DEPRECATED_NO_EXPORT KCMUTILSCORE_NO_EXPORT
#elif defined(KCMUTILSCORE_NO_DEPRECATED_WARNINGS)
#  define KCMUTILSCORE_DEPRECATED
#  define KCMUTILSCORE_DEPRECATED_EXPORT KCMUTILSCORE_EXPORT
#  define KCMUTILSCORE_DEPRECATED_NO_EXPORT KCMUTILSCORE_NO_EXPORT
#else
#  define KCMUTILSCORE_DEPRECATED KCMUTILSCORE_DECL_DEPRECATED
#  define KCMUTILSCORE_DEPRECATED_EXPORT KCMUTILSCORE_DECL_DEPRECATED_EXPORT
#  define KCMUTILSCORE_DEPRECATED_NO_EXPORT KCMUTILSCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCMUTILSCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCMUTILSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCMUTILSCORE_NO_DEPRECATED
#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
#endif
#ifdef KCMUTILSCORE_NO_DEPRECATED_WARNINGS
#  define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x57400
#  endif
#endif

#ifndef KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCMUTILSCORE_DEPRECATED
#  define KCMUTILSCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCMUTILSCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KCMUTILSCORE_EXPORT_H */
